# Cob

<img src="https://github.com/getweber/cob/raw/develop/doc/_static/logo-small.png" >


![Build Status] (https://secure.travis-ci.org/getweber/cob.png )

Cob is a tool for building ambitious webapps using Python. It is greatly inspired by Ember's [ember-cli](https://ember-cli.com/).

Please see the [documentation](http://cob.readthedocs.org) for more information.

# Licence

BSD3

